@@ -1,10 +1,13 @@
+import os
+currentPath = os.path.dirname(os.path.abspath(__file__))
+
 class MainConfig:
     """
     this is the main configuration file and is the only one which
     should need to be changed
     """
     # this is the port to which clients will connect
-    CoTServiceIP = int(8087)
+    CoTServicePort = int(8087)
 
     # this needs to be changed for private data packages to work
     DataPackageServiceDefaultIP = str("0.0.0.0")
@@ -13,7 +16,10 @@ class MainConfig:
     SaveCoTToDB = bool(False)
 
     # this should be set before startup
-    DBFilePath = str('FTSDataBase.db')
+    DBFilePath = str(currentPath + r'\FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
-    version = 'FreeTAKServer-1.1RC6'
\ No newline at end of file
+    version = 'FreeTAKServer-1.1'
+
+    # set to None if you don't want a message sent
+    ConnectionMessage = f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'
\ No newline at end of file
